#[repr(transparent)]pub struct Srsr(pub u32);Expand description
SRC Reset Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Srsr
impl Srsr
Sourcepub const fn ipp_reset_b(&self) -> IppResetB
pub const fn ipp_reset_b(&self) -> IppResetB
Indicates whether reset was the result of ipp_reset_b pin (Power-up sequence)
Sourcepub const fn set_ipp_reset_b(&mut self, val: IppResetB)
pub const fn set_ipp_reset_b(&mut self, val: IppResetB)
Indicates whether reset was the result of ipp_reset_b pin (Power-up sequence)
Sourcepub const fn lockup_sysresetreq(&self) -> LockupSysresetreq
pub const fn lockup_sysresetreq(&self) -> LockupSysresetreq
Indicates a reset has been caused by CPU lockup or software setting of SYSRESETREQ bit in Application Interrupt and Reset Control Register of the Arm core
Sourcepub const fn set_lockup_sysresetreq(&mut self, val: LockupSysresetreq)
pub const fn set_lockup_sysresetreq(&mut self, val: LockupSysresetreq)
Indicates a reset has been caused by CPU lockup or software setting of SYSRESETREQ bit in Application Interrupt and Reset Control Register of the Arm core
Sourcepub const fn csu_reset_b(&self) -> CsuResetB
pub const fn csu_reset_b(&self) -> CsuResetB
Indicates whether the reset was the result of the csu_reset_b input.
Sourcepub const fn set_csu_reset_b(&mut self, val: CsuResetB)
pub const fn set_csu_reset_b(&mut self, val: CsuResetB)
Indicates whether the reset was the result of the csu_reset_b input.
Sourcepub const fn ipp_user_reset_b(&self) -> IppUserResetB
pub const fn ipp_user_reset_b(&self) -> IppUserResetB
Indicates whether the reset was the result of the ipp_user_reset_b qualified reset.
Sourcepub const fn set_ipp_user_reset_b(&mut self, val: IppUserResetB)
pub const fn set_ipp_user_reset_b(&mut self, val: IppUserResetB)
Indicates whether the reset was the result of the ipp_user_reset_b qualified reset.
Sourcepub const fn wdog_rst_b(&self) -> WdogRstB
pub const fn wdog_rst_b(&self) -> WdogRstB
IC Watchdog Time-out reset
Sourcepub const fn set_wdog_rst_b(&mut self, val: WdogRstB)
pub const fn set_wdog_rst_b(&mut self, val: WdogRstB)
IC Watchdog Time-out reset
Sourcepub const fn jtag_rst_b(&self) -> JtagRstB
pub const fn jtag_rst_b(&self) -> JtagRstB
HIGH - Z JTAG reset. Indicates whether the reset was the result of HIGH-Z reset from JTAG.
Sourcepub const fn set_jtag_rst_b(&mut self, val: JtagRstB)
pub const fn set_jtag_rst_b(&mut self, val: JtagRstB)
HIGH - Z JTAG reset. Indicates whether the reset was the result of HIGH-Z reset from JTAG.
Sourcepub const fn jtag_sw_rst(&self) -> JtagSwRst
pub const fn jtag_sw_rst(&self) -> JtagSwRst
JTAG software reset. Indicates whether the reset was the result of software reset from JTAG.
Sourcepub const fn set_jtag_sw_rst(&mut self, val: JtagSwRst)
pub const fn set_jtag_sw_rst(&mut self, val: JtagSwRst)
JTAG software reset. Indicates whether the reset was the result of software reset from JTAG.
Sourcepub const fn wdog3_rst_b(&self) -> Wdog3RstB
pub const fn wdog3_rst_b(&self) -> Wdog3RstB
IC Watchdog3 Time-out reset
Sourcepub const fn set_wdog3_rst_b(&mut self, val: Wdog3RstB)
pub const fn set_wdog3_rst_b(&mut self, val: Wdog3RstB)
IC Watchdog3 Time-out reset
Sourcepub const fn tempsense_rst_b(&self) -> TempsenseRstB
pub const fn tempsense_rst_b(&self) -> TempsenseRstB
Temper Sensor software reset
Sourcepub const fn set_tempsense_rst_b(&mut self, val: TempsenseRstB)
pub const fn set_tempsense_rst_b(&mut self, val: TempsenseRstB)
Temper Sensor software reset